@@ -1,37 +1,26 @@
 import torch
 import torch.nn.functional as F
 from datetime import datetime
+from deprecated import deprecated
+from hover.core import Loggable
 from hover.utils.metrics import classification_accuracy
-from wasabi import msg as logger
 from sklearn.metrics import confusion_matrix
 from snorkel.classification import cross_entropy_with_probs
 import numpy as np
 
 
+@deprecated(
+    version="0.4.0",
+    reason="will be removed in a future version; please use VectorNet.from_module() instead.",
+)
 def create_vector_net_from_module(specific_class, model_module_name, labels):
     """
-    Create a TextVectorNet model, or of its child class.
-
-    - param specific_class(class): TextVectorNet or its child class.
-    - param model_module_name(str): path to a local Python module in the working directory whose __init__.py file contains a get_vectorizer() callable, get_architecture() callable, and a get_state_dict_path() callable.
-    - param labels(list of str): the classification labels, e.g. ["POSITIVE", "NEGATIVE"].
+    Deprecated into a trivial invocation of VectorNet's class method.
     """
-    from importlib import import_module
-
-    model_module = import_module(model_module_name)
-
-    # Load the model by retrieving the inp-to-vec function, architecture, and state dict
-    model = specific_class(
-        model_module.get_vectorizer(),
-        model_module.get_architecture(),
-        model_module.get_state_dict_path(),
-        labels,
-    )
-
-    return model
+    return specific_class.from_module(model_module_name, labels)
 
 
-class VectorNet(object):
+class VectorNet(Loggable):
 
     """
     Simple transfer learning model: a user-supplied vectorizer followed by a neural net.
@@ -68,7 +57,7 @@ class VectorNet(object):
             try:
                 self.nn.load_state_dict(torch.load(state_dict_path))
             except Exception as e:
-                logger.warn(f"Load VectorNet state path failed with {type(e)}: e")
+                self._warn(f"Load VectorNet state path failed with {type(e)}: e")
 
             state_dict_backup_path = (
                 f"{state_dict_path}.{datetime.now().strftime('%Y%m%d%H%M%S')}"
@@ -82,6 +71,29 @@ class VectorNet(object):
         self.nn_optimizer = torch.optim.Adam(self.nn.parameters())
         self._dynamic_params = {"optimizer": {"lr": 0.01, "betas": (0.9, 0.999)}}
 
+    @classmethod
+    def from_module(cls, model_module, labels):
+        """
+        Create a VectorNet model, or of its child class.
+
+        - param model_module(module or str): (path to) a local Python module in the working directory whose __init__.py file contains a get_vectorizer() callable, get_architecture() callable, and a get_state_dict_path() callable.
+        - param labels(list of str): the classification labels, e.g. ["POSITIVE", "NEGATIVE"].
+        """
+        if isinstance(model_module, str):
+            from importlib import import_module
+
+            model_module = import_module(model_module)
+
+        # Load the model by retrieving the inp-to-vec function, architecture, and state dict
+        model = cls(
+            model_module.get_vectorizer(),
+            model_module.get_architecture(),
+            model_module.get_state_dict_path(),
+            labels,
+        )
+
+        return model
+
     def save(self, save_path=None):
         """
         Save the current state dict with authorization to overwrite.
@@ -176,7 +188,7 @@ class VectorNet(object):
         if verbose > 0:
             log_info = dict(self._dynamic_params)
             log_info["performance"] = "Acc {0:.3f}".format(accuracy)
-            logger.info(
+            self._info(
                 "{0: <80}".format(
                     "Eval: Epoch {epoch} {performance}".format(**log_info)
                 )
@@ -230,7 +242,7 @@ class VectorNet(object):
         if verbose > 0:
             log_info = dict(self._dynamic_params)
             log_info["performance"] = "Loss {0:.3f}".format(loss)
-            print(
+            self._print(
                 "{0: <80}".format(
                     "Train: Epoch {epoch} Batch {batch} {performance}".format(
                         **log_info
