@@ -31,21 +31,57 @@ def dummy_vectorizer(spacy_en_md):
 
 
 @pytest.fixture(scope="module")
-def generate_text_df_with_coords():
-    def random_text_df_with_coords(size=300):
+def dummy_vecnet_callback():
+    from hover.core.neural import VectorNet
+    from hover.utils.common_nn import LogisticRegression
+
+    def callback(dataset, vectorizer):
+        vecnet = VectorNet(
+            vectorizer, LogisticRegression, ".model.test.pt", dataset.classes
+        )
+        return vecnet
+
+    return callback
+
+
+@pytest.fixture(scope="module")
+def dummy_labeling_function_list():
+    from hover.utils.snorkel_helper import labeling_function
+    from hover.module_config import ABSTAIN_DECODED
+
+    @labeling_function(targets=["rec.autos"])
+    def auto_keywords(row):
+        flag = re.search(r"(wheel|diesel|gasoline|automobile|vehicle)", row.text)
+        return "rec.autos" if flag else ABSTAIN_DECODED
+
+    @labeling_function(targets=["rec.sport.baseball"])
+    def baseball_keywords(row):
+        flag = re.search(r"(baseball|stadium|\ bat\ |\ base\ )", row.text)
+        return "rec.sport.baseball" if flag else ABSTAIN_DECODED
+
+    lf_list = [auto_keywords, baseball_keywords]
+
+    return lf_list
+
+
+@pytest.fixture(scope="module")
+def generate_df_with_coords():
+    def random_df_with_coords(size=300):
         df = pd.DataFrame(
             [
                 {
                     "text": fake_en.paragraph(3),
+                    "audio": "https://www.soundjay.com/button/beep-01a.mp3",
+                    "image": "https://docs.chainer.org/en/stable/_images/5.png",
                     "x": random.uniform(-1.0, 1.0),
                     "y": random.uniform(-1.0, 1.0),
                 }
-                for i in range(300)
+                for i in range(size)
             ]
         )
         return df
 
-    return random_text_df_with_coords
+    return random_df_with_coords
 
 
 @pytest.fixture(scope="module")
